==> kubernetes-model-apiextensions-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookClientConfigFluent<A extends WebhookClientConfigFluent<A>> extends Fluent<A>{
  public String getCaBundle();
  public A withCaBundle(String caBundle);
  public Boolean hasCaBundle();
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceReference getService();
  public ServiceReference buildService();
  public A withService(ServiceReference service);
  public Boolean hasService();
  public A withNewService(String name,String namespace,String path,Integer port);
  public WebhookClientConfigFluent.ServiceNested<A> withNewService();
  public WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(ServiceReference item);
  public WebhookClientConfigFluent.ServiceNested<A> editService();
  public WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
  public WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(ServiceReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceNested<N> extends Nested<N>,ServiceReferenceFluent<WebhookClientConfigFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface WebhookClientConfigFluent<A extends WebhookClientConfigFluent<A>> extends Fluent<A>{
  public String getCaBundle();
  public A withCaBundle(String caBundle);
  public Boolean hasCaBundle();
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceReference getService();
  public ServiceReference buildService();
  public A withService(ServiceReference service);
  public Boolean hasService();
  public A withNewService(String name,String namespace,String path,Integer port);
  public WebhookClientConfigFluent.ServiceNested<A> withNewService();
  public WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(ServiceReference item);
  public WebhookClientConfigFluent.ServiceNested<A> editService();
  public WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
  public WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(ServiceReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceNested<N> extends Nested<N>,ServiceReferenceFluent<WebhookClientConfigFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}
